@@ -4,7 +4,7 @@ from bs4 import BeautifulSoup
 import urllib2
 import os
 
-def downloadToMP3(url, folder, subfolder=""):
+def downloadToMP3(url, folder subfolder=""):
     video = pafy.new(url)
     best = video.getbest()
     folder = folder+subfolder
@@ -12,10 +12,8 @@ def downloadToMP3(url, folder, subfolder=""):
         os.makedirs(folder)
 
     path = folder+best.title+"."+best.extension
-    brackets = [best.title.find('('), best.title.find('[')]
-    
     artist = best.title[:(best.title.find(' -'))]
-    song = best.title[(best.title.find('- '))+2:min(brackets)]
+    song = best.title[(best.title.find('- '))+2:]
     best.download(filepath=path, quiet=False)
     vidFile = AudioSegment.from_file(path, best.extension)
     vidFile.export(folder+best.title+".mp3", format="mp3", tags={'artist': artist, 'title': song})
@@ -41,10 +39,9 @@ def downloadSong(artist, song, folder):
     result = results.find("li")
     data = result.find("h3", {"class":"yt-lockup-title"})
     songURL = "http://www.youtube.com" + data.find("a")['href']
-    print(songURL)
     downloadToMP3(songURL, folder)
     
-def downloadTop(artist, folder, number=5):
+def downloadTop(artist, number=5, folder):
     artistRep = artist.replace(' ','+')
     url = "http://www.youtube.com/results?search_query="+artistRep+"&filters=video"
     soup = BeautifulSoup(urllib2.urlopen(url))
